=======
History
=======

0.1.0 (2019-01-01)
------------------

* First release on PyPI.

0.1.1 (2019-01-17)
------------------

* First cut at a functioning module.  Tests, docs & builds are passing and a decent amount of functionality has been added, so a small version update felt appropriate.  0.1.2 should bring some exciting developments!

0.1.2 (2019-01-20)
------------------

* The module is indeed functioning! Added some new functionality like a skeleton for historical searching & plotting, strict searching, lots of bug fixes, fleshed out most of the
remaining parts of the ProductSearch and Product methods, and increased test coverage.  Also did some cleanup work moving classes and functions to specific models instead of importing from one module.  Plans for 0.1.3 include finishing out the plotting methods, separating concerns re: tests, and maybe more.